@@ -3,7 +3,7 @@ import inspect
 import logging
 import traceback
 import typing
-from typing import Any
+from typing import Any, ClassVar
 
 import gevent
 from pydantic.v1 import (
@@ -16,19 +16,37 @@ from mxcubeweb.core.models.adaptermodels import (
     HOActuatorModel,
     HOModel,
 )
-from mxcubeweb.core.util.adapterutils import get_adapter_cls_from_hardware_object
+from mxcubeweb.core.models.configmodels import AdapterResourceHandlerConfigModel
+from mxcubeweb.core.server.resource_handler import (
+    AdapterResourceHandlerFactory,
+)
+
+default_resource_handler_config = AdapterResourceHandlerConfigModel(
+    commands=[
+        "set_value",
+        "get_value",
+    ],
+    attributes=["data"],
+)
 
 
 class AdapterBase:
     """Hardware Object Adapter Base class"""
 
+    # List of supported HO base classes (or callable for more advanced matching)
+    SUPPORTED_TYPES: ClassVar[list[object]] = []
+    # Dictionary of supported types and their adapters
+    SUPPORTED_TYPES_TO_ADAPTERS = {}
+
     ATTRIBUTES = []
     METHODS = []
 
-    def __init__(self, ho, role, app):
+    ADAPTER_DICT = {}
+
+    def __init__(self, ho, role, app, resource_handler_config=None):
         """
         Args:
-            (object): Hardware object to mediate for.
+            ho (object): Hardware object to mediate for.
             (str): The name of the object
         """
         self.app = app
@@ -40,27 +58,52 @@ class AdapterBase:
         self._unique = True
         self._msg = ""
 
+        cls_name = self.__class__.__name__.lower()
+
+        if cls_name not in self.ADAPTER_DICT:
+            self.ADAPTER_DICT[cls_name] = {}
+
+        if ho is not None:
+            self.ADAPTER_DICT[cls_name][ho.name] = self
+
+        if resource_handler_config:
+            AdapterResourceHandlerFactory.create_or_get(
+                name=cls_name,
+                url_prefix="/mxcube/api/v0.1/hwobj/" + self._type.lower(),
+                adapter_dict=self.ADAPTER_DICT[cls_name],
+                app=self.app,
+                exports=resource_handler_config.exports,
+                commands=resource_handler_config.commands,
+                attributes=resource_handler_config.attributes,
+            )
+
+    @classmethod
+    def can_adapt(cls, ho):
+        return any(isinstance(ho, t) for t in cls.SUPPORTED_TYPES)
+
+    def __init_subclass__(cls, **kwargs):
+        for ho_class in cls.SUPPORTED_TYPES:
+            if ho_class in AdapterBase.SUPPORTED_TYPES_TO_ADAPTERS:
+                error_msg = ("Adapter for class %s already exists", ho_class.__name__)
+                raise ValueError(error_msg)
+            AdapterBase.SUPPORTED_TYPES_TO_ADAPTERS[ho_class] = cls
+        super().__init_subclass__(**kwargs)
+
+    @classmethod
+    def get_resource_handler(cls):
+        return AdapterBase.RESOURCE_HANDLER_DICT.get(cls.__name__, None)
+
     def get_adapter_id(self, ho=None):
         ho = ho if ho else self._ho
         return self.app.mxcubecore._get_adapter_id(ho)
 
-    def _add_adapter(self, attr_name, ho, adapter_cls=None):
-        adapter_cls = (
-            adapter_cls if adapter_cls else get_adapter_cls_from_hardware_object(ho)
-        )
-
+    def _add_adapter(self, attr_name, ho, adapter_cls):
         _id = f"{self.get_adapter_id()}.{attr_name}"
         adapter_instance = adapter_cls(ho, _id, self.app)
         self.app.mxcubecore._add_adapter(_id, adapter_cls, ho, adapter_instance)
 
         setattr(self, attr_name, adapter_instance)
 
-    def _set_value(self):
-        pass
-
-    def _get_value(self):
-        pass
-
     def execute_command(self, cmd_name, args):
         try:
             self._pydantic_model_for_command(cmd_name).validate(args)
@@ -204,19 +247,23 @@ class AdapterBase:
         exported_methods = {}
 
         # Get exported attributes from underlaying HardwareObject
-        if self._ho.exported_attributes:
-            exported_methods = self._ho.exported_attributes
+        # and only set display True for those methods that have
+        # been explicitly configured to be exported
+        configured_exported = self._ho.exported_attributes.keys()
 
-        for method_name in self.METHODS:
-            attr = getattr(self, method_name, None)
+        rh = AdapterResourceHandlerFactory.get_handler(self.__class__.__name__.lower())
 
-            if attr:
-                model = self._model_from_typehint(attr)
-                exported_methods[method_name] = {
-                    "signature": model["signature"],
-                    "schema": model["args"].schema_json(),
-                    "display": False,
-                }
+        if rh:
+            for export in rh.commands:
+                attr = getattr(self, export["attr"], None)
+
+                if inspect.ismethod(attr):
+                    model = self._model_from_typehint(attr)
+                    exported_methods[export["attr"]] = {
+                        "signature": model["signature"],
+                        "schema": model["args"].schema_json(),
+                        "display": export["attr"] in configured_exported,
+                    }
 
         return exported_methods
 
@@ -273,13 +320,13 @@ class AdapterBase:
         Signal handler to be used for sending the entire object to the client via
         socketIO
         """
-        data = self.dict()
+        data = self.data().dict()
 
         if hasattr(state, "name"):
             data["state"] = state.name
         else:
             logging.getLogger("MX3.HWR").info(
-                f"emit_ho_changed with {state} for {self._ho.name()}"
+                f"emit_ho_changed with {state} for {self._ho.name}"
             )
 
         self.app.server.emit("hardware_object_changed", data, namespace="/hwr")
@@ -330,21 +377,18 @@ class AdapterBase:
             )
         return data
 
-    def data(self):
+    def data(self) -> HOModel:
         return HOModel(**self._dict_repr())
 
-    def dict(self):
-        return self.data().dict()
-
 
 class ActuatorAdapterBase(AdapterBase):
-    def __init__(self, ho, *args):
+    def __init__(self, ho, role, app, resource_handler_config=None):
         """
         Args:
             (object): Hardware object to mediate for.
             (str): The name of the object.
         """
-        super().__init__(ho, *args)
+        super().__init__(ho, role, app, resource_handler_config)
 
         self._unique = False
 
@@ -362,28 +406,18 @@ class ActuatorAdapterBase(AdapterBase):
         self.emit_ho_value_changed(args[0])
 
     # Abstract method
-    def set_value(self, value):
+    def set_value(self, value) -> None:
         """
         Sets a value on underlying hardware object.
+
         Args:
             value(float): Value to be set.
-        Returns:
-            (str): The actual value, after being set.
         Raises:
             ValueError: When conversion or treatment of value fails.
             StopIteration: When a value change was interrupted (abort/cancel).
+        Emits:
+            hardware_object_value_changed with values over websocket
         """
-        try:
-            self._set_value(value)
-            data = self.dict()
-        except ValueError as ex:
-            self._available = False
-            data = self.dict()
-            data["state"] = "UNUSABLE"
-            data["msg"] = str(ex)
-            logging.getLogger("MX3.HWR").error("Error setting bl attribute: " + str(ex))
-
-        return data
 
     # Abstract method
     def get_value(self):
@@ -426,13 +460,13 @@ class ActuatorAdapterBase(AdapterBase):
         data = super()._dict_repr()
 
         try:
-            data.update({"value": self.get_value(), "limits": self.limits()})
+            data.update({"value": self.get_value().value, "limits": self.limits()})
         except Exception as ex:
             logging.getLogger("MX3.HWR").exception(
-                f"Could not get dictionary representation of {self._ho.name()}"
+                f"Could not get dictionary representation of {self._ho.name}"
             )
             logging.getLogger("MX3.HWR").error(
-                f"Check status of {self._ho.name()}, object is"
+                f"Check status of {self._ho.name}, object is"
                 " offline, in fault or returns unexpected value !"
             )
 
