@@ -217,10 +217,9 @@ class Queue(ComponentBase):
                 where state: {0, 1, 2, 3} = {in_queue, running, success, failed}
                 {'sample': sample, 'idx': index, 'queue_id': node_id}
         """
-        try:
-            node, entry = self.get_entry(node_id)
-        except Exception:
-            return (True, UNCOLLECTED)
+        if node_id is None:
+            return True, UNCOLLECTED
+        node, entry = self.get_entry(node_id)
 
         enabled = node.is_enabled()
         curr_entry = HWR.beamline.queue_manager.get_current_entry()
@@ -711,10 +710,8 @@ class Queue(ComponentBase):
         :rtype: Tuple
         """
         if _id is None:
-            return (
-                HWR.beamline.queue_model.get_model_root(),
-                HWR.beamline.queue_manager,
-            )
+            dummy_variable = "Cannot retrieve entry without a node id"
+            raise ValueError(dummy_variable)
         model = HWR.beamline.queue_model.get_node(int(_id))
         entry = HWR.beamline.queue_manager.get_entry_with_model(model)
         return model, entry
@@ -822,29 +819,6 @@ class Queue(ComponentBase):
 
         logging.getLogger("MX3.HWR").info("[QUEUE] is:\n%s " % self.queue_to_json())
 
-    def set_sample_order(self, order):
-        """
-        Set the sample order of the queue
-        :param list sample_order: List of sample ids
-        """
-        current_queue = self.queue_to_dict()
-        sid_list = [sid for sid in order if current_queue.get(sid, False)]
-
-        if sid_list:
-            queue_id_list = [current_queue[sid]["queueID"] for sid in sid_list]
-            model_entry_list = [self.get_entry(qid) for qid in queue_id_list]
-            model_list = [model_entry[0] for model_entry in model_entry_list]
-            entry_list = [model_entry[1] for model_entry in model_entry_list]
-
-            # Set the order in the queue model
-            HWR.beamline.queue_model.get_model_root()._children = model_list
-            # Set queue entry order
-            HWR.beamline.queue_manager._queue_entry_list = entry_list
-
-        self.app.lims.sample_list_set_order(order)
-
-        logging.getLogger("MX3.HWR").info("[QUEUE] is:\n%s " % self.queue_to_json())
-
     def queue_add_item(self, item_list):
         """
         Adds the queue items in item_list to the queue. The items in the list can
@@ -1038,9 +1012,7 @@ class Queue(ComponentBase):
         acq.path_template.start_num = params["first_image"]
         acq.path_template.num_files = params["num_images"]
         acq.path_template.suffix = ftype
-        acq.path_template.precision = "0" + str(
-            HWR.beamline.session["file_info"].get_property("precision", 4)
-        )
+        acq.path_template.precision = "0" + str(qmo.PathTemplate.precision)
 
         self.app.lims.apply_template(params, sample_model, acq.path_template)
 
@@ -1109,9 +1081,9 @@ class Queue(ComponentBase):
                 grid.width,
                 grid.height,
             )
-            mesh_center = HWR.beamline.default_acquisition_parameters["mesh"].get(
-                "mesh_center", "top-left"
-            )
+            mesh_center = HWR.beamline.get_default_acquisition_parameters(
+                "mesh"
+            ).mesh_center
             if mesh_center == "top-left":
                 acq.acquisition_parameters.centred_position = (
                     grid.get_centred_positions()[0]
@@ -1178,9 +1150,7 @@ class Queue(ComponentBase):
         model.path_template.set_from_dict(params)
         model.path_template.base_prefix = params["prefix"]
         model.path_template.num_files = 0
-        model.path_template.precision = "0" + str(
-            HWR.beamline.session["file_info"].get_property("precision", 4)
-        )
+        model.path_template.precision = "0" + str(qmo.PathTemplate.precision)
 
         self.app.lims.apply_template(params, sample_model, model.path_template)
 
@@ -1281,9 +1251,7 @@ class Queue(ComponentBase):
 
         model.path_template.set_from_dict(params)
         model.path_template.suffix = ftype
-        model.path_template.precision = "0" + str(
-            HWR.beamline.session["file_info"].get_property("precision", 4)
-        )
+        model.path_template.precision = "0" + str(qmo.PathTemplate.precision)
 
         if params["prefix"]:
             model.path_template.base_prefix = params["prefix"]
@@ -1326,9 +1294,7 @@ class Queue(ComponentBase):
 
         model.path_template.set_from_dict(params)
         model.path_template.suffix = ftype
-        model.path_template.precision = "0" + str(
-            HWR.beamline.session["file_info"].get_property("precision", 4)
-        )
+        model.path_template.precision = "0" + str(qmo.PathTemplate.precision)
 
         if params["prefix"]:
             model.path_template.base_prefix = params["prefix"]
@@ -1575,9 +1541,7 @@ class Queue(ComponentBase):
         acq.path_template.start_num = params["first_image"]
         acq.path_template.num_files = params["num_images"]
         acq.path_template.suffix = ftype
-        acq.path_template.precision = "0" + str(
-            HWR.beamline.session["file_info"].get_property("precision", 4)
-        )
+        acq.path_template.precision = "0" + str(qmo.PathTemplate.precision)
 
         if params["prefix"]:
             acq.path_template.base_prefix = params["prefix"]
@@ -1587,7 +1551,12 @@ class Queue(ComponentBase):
             )
 
         full_path, process_path = HWR.beamline.session.get_full_path(
-            os.path.join(params.get("subdir", ""), params.get("experiment_name", "")),
+            # Note that 'experiment_name' field can either be omitted, set to None
+            # or some string value. For cases it is not defined (omitted or None)
+            # the "" will be used for the path generation.
+            os.path.join(
+                params.get("subdir", ""), params.get("experiment_name", "") or ""
+            ),
             task_name,
         )
         acq.path_template.directory = full_path
@@ -1766,11 +1735,20 @@ class Queue(ComponentBase):
         added. Handles for instance the addition of reference collections for
         characterisations and workflows.
         """
-        _, parent_entry = self.get_entry(parent._node_id)
-        child_model, _ = self.get_entry(child._node_id)
+        if parent is HWR.beamline.queue_model.get_model_root():
+            parent_entry = HWR.beamline.queue_manager
+        else:
+            node_id = parent._node_id
+            if node_id is not None:
+                _, parent_entry = self.get_entry(parent._node_id)
+            else:
+                dummy_variable = (
+                    "Trying to add child {child} to unenqueued parent {parent}"
+                )
+                raise ValueError(dummy_variable)
 
         # Origin is ORIGIN_MX3 if task comes from MXCuBE-3
-        if child_model.get_origin() != ORIGIN_MX3:
+        if child.get_origin() != ORIGIN_MX3:
             if isinstance(child, qmo.DataCollection):
                 dc_entry = qe.DataCollectionQueueEntry(Mock(), child)
 
@@ -2184,7 +2162,7 @@ class Queue(ComponentBase):
         else:
             msg = "[QUEUE] Sample with id %s not in queue, can't update" % sid
             logging.getLogger("MX3.HWR").error(msg)
-            raise Exception(msg)
+            raise ValueError(msg)
 
     def toggle_node(self, node_id):
         node = HWR.beamline.queue_model.get_node(node_id)
@@ -2338,7 +2316,7 @@ class Queue(ComponentBase):
                 "subDirTemplate": "{ACRONYM}/{ACRONYM}-{NAME}",
                 "experiment_type": "",
             },
-            "limits": HWR.beamline.acquisition_limit_values,
+            "limits": HWR.beamline.config.acquisition_limit_values,
             "requires": requires if requires else [],
             "name": display_name if display_name else task_name,
             "queue_entry": task_name,
@@ -2368,7 +2346,7 @@ class Queue(ComponentBase):
     def get_available_tasks(self):
         task_info = {}
 
-        for task, available in HWR.beamline.available_methods.items():
+        for task, available in HWR.beamline.config.available_methods.items():
             if available:
                 task_info[task] = self.get_default_task_parameters(task)
 
@@ -2389,7 +2367,7 @@ class Queue(ComponentBase):
         if not sample:
             msg = "[QUEUE] sample info could not be retrieved"
             logging.getLogger("MX3.HWR").error(msg)
-            raise Exception(msg)
+            raise KeyError(msg)
         # Find task with queue id method_id
         for task in sample.tasks:
             if task["queueID"] == int(method_id):
@@ -2399,7 +2377,7 @@ class Queue(ComponentBase):
         msg += " the given sample"
         logging.getLogger("MX3.HWR").exception(msg)
 
-        raise Exception(msg)
+        raise ValueError(msg)
 
     def set_group_folder(self, path):
         if path and path[0] in ["/", "."]:
