@@ -1,5 +1,6 @@
 import datetime
 from enum import Enum
+from pathlib import Path
 from typing import (
     Literal,
 )
@@ -19,7 +20,12 @@ class FlaskConfigModel(BaseModel):
     ALLOWED_CORS_ORIGINS: list[str] = Field([], description="")
     SECURITY_PASSWORD_SALT: str = Field("ASALT", description="")
     SECURITY_TRACKABLE: bool = Field(True, description="")
-    USER_DB_PATH: str = Field("/tmp/mxcube-user.db", description="")
+    USER_DB_PATH: str = Field(
+        str(Path.home() / ".local" / "share" / "mxcube" / "mxcube-user.db"),
+        description="",
+    )
+    HOST: str = Field("127.0.0.1", description="Host address to bind to")
+    PORT: int = Field(8081, description="Port to bind to")
     PERMANENT_SESSION_LIFETIME: datetime.timedelta
     CERT_KEY: str = Field("", description="Full path to signed certificate key file")
     CERT_PEM: str = Field("", description="Full path to signed certificate pem file")
@@ -62,6 +68,7 @@ class UIComponentModel(BaseModel):
     value_type: str | None
     object_type: str | None
     format: str | None
+    invert_color_semantics: bool | None
 
 
 class _UICameraConfigModel(BaseModel):
@@ -101,11 +108,24 @@ class UISampleViewVideoControlsModel(UIPropertiesModel):
     ]
 
 
+class UiSessionPickerTabs(BaseModel):
+    active: bool = True
+    scheduled: bool = True
+    other_beamlines: bool = True
+    all_sessions: bool = False
+
+
+class UISessionPickerModel(BaseModel):
+    id: Literal["session_picker"] = "session_picker"
+    tabs: UiSessionPickerTabs = UiSessionPickerTabs()
+
+
 class UIPropertiesListModel(BaseModel):
     sample_view: UIPropertiesModel
     beamline_setup: UIPropertiesModel
     camera_setup: UICameraConfigModel | None
     sample_view_video_controls: UISampleViewVideoControlsModel | None
+    session_picker: UISessionPickerModel = UISessionPickerModel()
 
 
 class UserManagerUserConfigModel(BaseModel):
@@ -149,9 +169,20 @@ class MXCUBEAppConfigModel(BaseModel):
             "True to use video stream produced by external software, false otherwise"
         ),
     )
+    USE_GET_SAMPLES_FROM_SC: bool = Field(
+        True,
+        description=(
+            "True to acticvate or be able to get samples from the sample changer, false otherwise"
+        ),
+    )
     mode: ModeEnum = Field(
         ModeEnum.OSC, description="MXCuBE mode OSC, SSX-CHIP or SSX-INJECTOR"
     )
+    LOCAL_DOMAINS: list[str] = Field(
+        [],
+        description="If the connected client's hostname ends with one of these domains"
+        ", it will be considered 'local'",
+    )
     usermanager: UserManagerConfigModel
     ui_properties: dict[str, UIPropertiesModel] = {}
 
@@ -160,3 +191,65 @@ class AppConfigModel(BaseModel):
     server: FlaskConfigModel
     mxcube: MXCUBEAppConfigModel
     sso: SSOConfigModel | None
+
+
+class AdapterResourceHandlerConfigModel(BaseModel):
+    """
+    Used to define  which adapter properties and methods that are
+    exported over HTTP. An endpoint for each method and/or property
+    is created by the AdapterResourceHandler and attached to the server.
+
+    The exports list defines the methods and properties exported,
+    the HTTP verb to use and the decorators to apply to the view
+    function,
+
+    The format is:
+    [
+        {"attr": "get_value", "method": "PUT", "decorators":[]}
+    ]
+
+    Where "attr" is the method or property of the adapter, "method"
+    is the http verb i.e GET, PUT, POST. and decoratoes are a list
+    decroator functions to apply to the resulting view function.
+
+    There are two structures that can be used for convenience, that
+    use defualt vlaues for "method" and "decorators". These are
+    commands and attributes.
+
+    Commands is list of functions/methods to export.
+    A dictionary like the one above:
+
+        ({"attr": "get_value", "method": "PUT", "decorators":[]})
+
+    Will be generated from the commands list. With the values "method" and
+    decorators set to defualt values, PUT and [restrict, require_control]
+
+    Example:
+
+        commands = ["set_value", "get_value"]
+
+    Will export the methods as .../set_value with HTTP verb PUT
+
+    In the same way:
+
+    Example:
+
+        attributes = ["data"]
+
+    Will export the property as .../data with HTTP verb GET
+    """
+
+    url_prefix: str = Field("", description="URL prefix")
+    exports: list[dict[str, str]] = Field(
+        [],
+        description=(
+            "List of dictionaires specifying each of the exported attributes or"
+            " methods, HTTP method to use and decorators to apply "
+        ),
+    )
+    commands: list[str] = Field(
+        [], description="List of exported methods, defualted to HTTP PUT"
+    )
+    attributes: list[str] = Field(
+        [], description="List of exported properties, defaulted to HTTP GET"
+    )
