@@ -1,6 +1,5 @@
 import json
 
-import spectree
 from flask import (
     Blueprint,
     Response,
@@ -90,7 +89,7 @@ def init_route(app, server, url_prefix):  # noqa: C901
         server.emit("queue", msg, namespace="/hwr")
         return Response(status=200)
 
-    @bp.route("/clear", methods=["PUT", "GET"])
+    @bp.route("/clear", methods=["PUT"])
     @server.require_control
     @server.restrict
     def queue_clear():
@@ -250,18 +249,6 @@ def init_route(app, server, url_prefix):  # noqa: C901
 
         return Response(status=200)
 
-    @bp.route("/sample-order", methods=["POST"])
-    @server.require_control
-    @server.restrict
-    def queue_set_sample_order():
-        sample_order = request.get_json().get("sampleOrder", [])
-        app.queue.set_sample_order(sample_order)
-        server.emit(
-            "queue", {"Signal": "update", "message": "observers"}, namespace="/hwr"
-        )
-
-        return Response(status=200)
-
     @bp.route("/<sample_id>", methods=["PUT"])
     @server.require_control
     @server.restrict
@@ -381,10 +368,6 @@ def init_route(app, server, url_prefix):  # noqa: C901
     @bp.route("/setting", methods=["POST"])
     @server.require_control
     @server.restrict
-    @server.validate(
-        json=SimpleNameValue,
-        resp=spectree.Response("HTTP_409", "HTTP_200"),
-    )
     def set_setting():
         result = app.queue.set_setting(SimpleNameValue(**request.json))
 
