@@ -1,6 +1,7 @@
 import logging
 import os
 import traceback
+from pathlib import Path
 
 import flask_security
 import gevent
@@ -10,7 +11,6 @@ from flask import (
     request,
 )
 from flask_socketio import SocketIO
-from spectree import SpecTree
 from werkzeug.middleware.proxy_fix import ProxyFix
 
 from mxcubeweb.core.components.user.database import (
@@ -22,6 +22,7 @@ from mxcubeweb.core.models.usermodels import (
     Role,
     User,
 )
+from mxcubeweb.core.server.resource_handler import AdapterResourceHandlerFactory
 from mxcubeweb.core.util import networkutils
 
 
@@ -71,15 +72,6 @@ class Server:
         )
         Server.flask_socketio.init_app(Server.flask)
 
-        Server.api = SpecTree(
-            "flask",
-            app=Server.flask,
-            title="MXCuBE Web api",
-            version="v1.0",
-            annotations=True,
-        )
-        Server.validate = Server.api.validate
-
         # the following test prevents Flask from initializing twice
         # (because of the Reloader)
         if not Server.flask.debug or os.environ.get("WERKZEUG_RUN_MAIN") == "true":
@@ -91,13 +83,14 @@ class Server:
 
     def _register_route(init_blueprint_fn, app, url_prefix):
         bp = init_blueprint_fn(app, Server, url_prefix)
-
         Server.flask.register_blueprint(bp)
 
         for key, function in Server.flask.view_functions.items():
             if key.startswith(bp.name) and not hasattr(function, "tags"):
                 function.tags = [bp.name.title().replace("_", " ")]
 
+        return bp
+
     @staticmethod
     def register_routes(mxcube):
         Server.security = flask_security.Security(
@@ -114,7 +107,6 @@ class Server:
         from mxcubeweb.routes.log import init_route as init_log_route
         from mxcubeweb.routes.login import init_route as init_login_route
         from mxcubeweb.routes.main import init_route as init_main_route
-        from mxcubeweb.routes.mockups import init_route as init_mockups_route
         from mxcubeweb.routes.queue import init_route as init_queue_route
         from mxcubeweb.routes.ra import init_route as init_ra_route
         from mxcubeweb.routes.samplecentring import init_route as init_sampleview_route
@@ -147,8 +139,6 @@ class Server:
 
         Server._register_route(init_main_route, mxcube, f"{url_root_prefix}")
 
-        Server._register_route(init_mockups_route, mxcube, f"{url_root_prefix}/mockups")
-
         Server._register_route(init_queue_route, mxcube, f"{url_root_prefix}/queue")
 
         Server._register_route(init_ra_route, mxcube, f"{url_root_prefix}/ra")
@@ -173,7 +163,7 @@ class Server:
             init_harvester_route, mxcube, f"{url_root_prefix}/harvester"
         )
 
-        Server.security = flask_security.Security(Server.flask, Server.user_datastore)
+        AdapterResourceHandlerFactory.register_with_server(Server.flask)
 
     @staticmethod
     def emit(*args, **kwargs):
@@ -186,8 +176,9 @@ class Server:
                 cfg.flask.CERT_PEM, cfg.flask.CERT_KEY
             )
         elif cfg.flask.CERT == "ADHOC":
+            cert_dir = Path(cfg.flask.USER_DB_PATH).parent
             ssl_context = werkzeug.serving.load_ssl_context(
-                *werkzeug.serving.make_ssl_devcert("/tmp/")
+                *werkzeug.serving.make_ssl_devcert(str(cert_dir))
             )
         else:
             ssl_context = None
@@ -196,8 +187,8 @@ class Server:
             Server.flask_socketio.run(
                 Server.flask,
                 ssl_context=ssl_context,
-                host="0.0.0.0",
-                port=8081,
+                host=cfg.flask.HOST,
+                port=cfg.flask.PORT,
             )
         else:
-            Server.flask_socketio.run(Server.flask, host="0.0.0.0", port=8081)
+            Server.flask_socketio.run(Server.flask, cfg.flask.HOST, port=cfg.flask.PORT)
